package com.pm.waring.mapper;

import java.util.List;

import com.pm.common.config.PageData;
/**
 * 设备告警Mapper接口
 *
 * @author LiXiangFei
 * @date 2025-04-16
 */
public interface IbmsDeviceAlarmMapper
{
    /**
     * 查询设备告警
     *
     * @param id 设备告警主键
     * @return 设备告警
     */
    public PageData selectIbmsDeviceAlarmById(Long id);

    /**
     * 查询设备告警列表
     *
     * @param pd 设备告警
     * @return 设备告警集合
     */
    public List<PageData> selectIbmsDeviceAlarmList(PageData pd);

    /**
     * 新增设备告警
     *
     * @param pd 设备告警
     * @return 结果
     */
    public int insertIbmsDeviceAlarm(PageData pd);

    /**
     * 修改设备告警
     *
     * @param pd 设备告警
     * @return 结果
     */
    public int updateIbmsDeviceAlarm(PageData pd);

    /**
     * 删除设备告警
     *
     * @param id 设备告警主键
     * @return 结果
     */
    public int deleteIbmsDeviceAlarmById(Long id);

    /**
     * 批量删除设备告警
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIbmsDeviceAlarmByIds(Long[] ids);
}
